@@ -1,12 +1,14 @@
 use std::ops::IndexMut;
 
-pub trait Array: IndexMut<usize>
+pub trait Array: Sized + IndexMut<usize>
 where
     Self::Output: Sized,
 {
+    type Item;
     const SIZE: usize;
 }
 
 impl<Item, const SIZE: usize> Array for [Item; SIZE] {
+    type Item = Item;
     const SIZE: usize = SIZE;
-}
\ No newline at end of file
+}
